# Cadwork Python Interface

[![PyPI](https://img.shields.io/pypi/v/cwapi3d)](https://pypi.python.org/pypi/cwapi3d/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cwapi3d)](https://pypi.python.org/pypi/cwapi3d/)
[![RTD](https://img.shields.io/readthedocs/cwapi3dpython)](https://python.cadwork.dev)
[![Issues](https://img.shields.io/github/issues/cwapi3d/cwapi3dpython)](https://github.com/cwapi3d/cwapi3dpython/issues)
[![Pulls](https://img.shields.io/github/issues-pr/cwapi3d/cwapi3dpython)](https://github.com/cwapi3d/cwapi3dpython/pulls)
[![GitHub](https://img.shields.io/github/license/cwapi3d/cwapi3dpython)](https://choosealicense.com/licenses/mit/)

This is the Cadwork 3D CwAPI3D plugin architecture in Python.

## Installation

Install with pip:

```bash
  pip install cwapi3d
```
    
## Contributing

Contributions are always welcome!
  
## Roadmap

- Guides
- Examples
- API Documentation
  
## Authors

- [@jspaquet](https://github.com/jspaquet)
- [@Brunner246](https://github.com/Brunner246)
  
## License

[MIT](https://choosealicense.com/licenses/mit/)
